@@ -645,7 +645,7 @@ test_that("direct reation of periods works as expected", {
 })
 
 
-test_that("period arithmetics works with infinite times", {
+test_that("period arithmetic works with infinite times", {
   #1113
   skip("FIXME: activate when timechange#29 isfixed")
   date <- ymd("2023-01-01")
